@@ -35,7 +35,6 @@ from text_alignment_tool.shared_classes import (
 from text_alignment_tool.text_loaders import (
     TextLoader,
     AltoXMLTextLoader,
-    PgpXmlTeiTextLoader,
     StringTextLoader,
     NewlineSeparatedTextLoader,
 )
@@ -51,4 +50,5 @@ from text_alignment_tool.text_transformers import (
     SubstituteMultipleCharactersTransformer,
     BracketingPair,
     ConsistentBracketingTransformer,
+    RemoveEnclosedTransformer,
 )
