@@ -7,6 +7,7 @@ from text_alignment_tool.shared_classes import (
     LetterList,
     TextAlignments,
 )
+from text_alignment_tool.analyzers import compare_parallel_text_chunks
 from text_alignment_tool.text_transformers import TextTransformer
 from typing import NamedTuple, Union
 from enum import Enum
@@ -111,6 +112,19 @@ class QueryTargetAlignment:
     def target_transformer_class_name(self):
         return self.__target_transformer_class_name
 
+    @property
+    def visualize_alignment(self) -> str:
+        return str(self)
+
+    @property
+    def visualize_chunk_alignment(self) -> str:
+        return compare_parallel_text_chunks(
+            self.query_text,
+            [x[0] for x in self.query_to_target_chunk_mapping],
+            self.target_text,
+            [x[1] for x in self.query_to_target_chunk_mapping],
+        )
+
     def __str__(self):
         query_to_target_alignment = {
             x.query_idx: chr(self.target_text[x.target_idx])
