@@ -257,6 +257,17 @@ class TextAlignmentTool:
                     latest_alignment = stored_alignment
                 results.append(current_query_target_alignment)
 
+        # Make sure to include the final alignment
+        final_alignment = QueryTargetAlignment(
+            self.latest_alignment._alignment,
+            self.__latest_query_text,
+            self.__latest_target_text,
+            self.__latest_query_text_chunk_indices,
+            self.__latest_target_text_chunk_indices,
+            self.__latest_query_transform.__class__.__name__,
+            self.__latest_target_transform.__class__.__name__,
+        )
+        results.insert(0, [final_alignment])
         return results
 
     # def find_alignment_to_query(self) -> list[QueryTargetAlignment]:
