@@ -20,11 +20,11 @@ class AltoAlignmentMap(NamedTuple):
 
 class AltoXMLTextLoader(TextLoader):
     def __init__(
-        self, file_paths: list[Path], estimated_number_of_lines_per_page: int = 60
+        self, file_path: Path, estimated_number_of_lines_per_page: int = 60
     ):
         self.__serialized_xml = pd.DataFrame()
         self.__estimated_number_of_lines_per_page = estimated_number_of_lines_per_page
-        super().__init__(file_paths)
+        super().__init__(file_path)
         self._input_output_map: list[AltoAlignmentMap] = []
 
     def _load(self) -> LetterList:
@@ -44,7 +44,7 @@ class AltoXMLTextLoader(TextLoader):
             chunk_end_idx = token_idx_count
             if chunk_start_idx < chunk_end_idx:
                 self._text_chunk_indices.append(
-                    TextChunk(chunk_start_idx, chunk_end_idx)
+                    TextChunk(list(range(chunk_start_idx, chunk_end_idx + 1)), str(row.line_ID))
                 )
         self._output: LetterList = np.array(tokens)
 
@@ -89,160 +89,157 @@ class AltoXMLTextLoader(TextLoader):
                 "linetagID": pd.Series([], dtype=pd.StringDtype()),
                 "xml_filename": pd.Series([], dtype=pd.StringDtype()),
             },
-            index=range(
-                len(self._file_paths) * self.__estimated_number_of_lines_per_page
-            ),
+            index=range(self.__estimated_number_of_lines_per_page),
         )  # Start with a reasonably sized table
         order = 0
         image_count = 0
         cumulative_text_length = 0
 
-        for xml_file_path in self._file_paths:
-            with open(xml_file_path, "rb") as xml_data:
-                events = ("start", "end")
-                needed_elements = DotMap(
-                    {
-                        "file_name": "{http://www.loc.gov/standards/alto/ns-v4#}fileName",
-                        "page": "{http://www.loc.gov/standards/alto/ns-v4#}Page",
-                        "description": "{http://www.loc.gov/standards/alto/ns-v4#}Description",
-                        "other_tag": "{http://www.loc.gov/standards/alto/ns-v4#}OtherTag",
-                        "text_block": "{http://www.loc.gov/standards/alto/ns-v4#}TextBlock",
-                        "polygon": "{http://www.loc.gov/standards/alto/ns-v4#}Polygon",
-                        "text_line": "{http://www.loc.gov/standards/alto/ns-v4#}TextLine",
-                        "string": "{http://www.loc.gov/standards/alto/ns-v4#}String",
-                    }
-                )
-                image_filename = ""
-                image_height = 0
-                image_width = 0
-                tag_dict = {}
+        with open(self._file_path, "rb") as xml_data:
+            events = ("start", "end")
+            needed_elements = DotMap(
+                {
+                    "file_name": "{http://www.loc.gov/standards/alto/ns-v4#}fileName",
+                    "page": "{http://www.loc.gov/standards/alto/ns-v4#}Page",
+                    "description": "{http://www.loc.gov/standards/alto/ns-v4#}Description",
+                    "other_tag": "{http://www.loc.gov/standards/alto/ns-v4#}OtherTag",
+                    "text_block": "{http://www.loc.gov/standards/alto/ns-v4#}TextBlock",
+                    "polygon": "{http://www.loc.gov/standards/alto/ns-v4#}Polygon",
+                    "text_line": "{http://www.loc.gov/standards/alto/ns-v4#}TextLine",
+                    "string": "{http://www.loc.gov/standards/alto/ns-v4#}String",
+                }
+            )
+            image_filename = ""
+            image_height = 0
+            image_width = 0
+            tag_dict = {}
 
-                zone_on_page_count = 0
-                region_id = ""
-                region_type_id = ""
-                x_region = 0
-                y_region = 0
-                w_region = 0
-                h_region = 0
-                region_polygon = ""
-                last_parent_tag = ""
+            zone_on_page_count = 0
+            region_id = ""
+            region_type_id = ""
+            x_region = 0
+            y_region = 0
+            w_region = 0
+            h_region = 0
+            region_polygon = ""
+            last_parent_tag = ""
 
-                line_in_zone_count = 0
-                line_id = ""
-                line_type_id = ""
-                x = 0
-                y = 0
-                w = 0
-                h = 0
-                line_polygon = ""
-                line_baseline = ""
-                line_text = ""
+            line_in_zone_count = 0
+            line_id = ""
+            line_type_id = ""
+            x = 0
+            y = 0
+            w = 0
+            h = 0
+            line_polygon = ""
+            line_baseline = ""
+            line_text = ""
 
-                for action, element in etree.iterparse(
-                    xml_data, events=events, tag=needed_elements.values()
-                ):
-                    if action == "start":
-                        if element.tag == needed_elements.text_line:
-                            line_in_zone_count += 1
-                            line_id = element.attrib["ID"]
-                            line_type_id = element.attrib.get("TAGREFS", "")
-                            y = int(float(element.attrib.get("VPOS", 0)))
-                            x = int(float(element.attrib.get("HPOS", 0)))
-                            h = int(float(element.attrib.get("HEIGHT", 0)))
-                            w = int(float(element.attrib.get("WIDTH", 0)))
-                            line_baseline = element.attrib.get("BASELINE", "")
-                            last_parent_tag = element.tag
+            for action, element in etree.iterparse(
+                xml_data, events=events, tag=needed_elements.values()
+            ):
+                if action == "start":
+                    if element.tag == needed_elements.text_line:
+                        line_in_zone_count += 1
+                        line_id = element.attrib["ID"]
+                        line_type_id = element.attrib.get("TAGREFS", "")
+                        y = int(float(element.attrib.get("VPOS", 0)))
+                        x = int(float(element.attrib.get("HPOS", 0)))
+                        h = int(float(element.attrib.get("HEIGHT", 0)))
+                        w = int(float(element.attrib.get("WIDTH", 0)))
+                        line_baseline = element.attrib.get("BASELINE", "")
+                        last_parent_tag = element.tag
 
-                        elif element.tag == needed_elements.string:
-                            line_text = element.attrib.get("CONTENT", "")
+                    elif element.tag == needed_elements.string:
+                        line_text = element.attrib.get("CONTENT", "")
 
-                        elif element.tag == needed_elements.polygon:
-                            if last_parent_tag == needed_elements.text_line:
-                                line_polygon = element.attrib.get(
-                                    "POINTS", self.__poly_from_coords(x, y, w, h)
-                                )
-                            elif last_parent_tag == needed_elements.text_block:
-                                region_polygon = element.attrib.get(
-                                    "POINTS",
-                                    self.__poly_from_coords(
-                                        x_region, y_region, w_region, h_region
-                                    ),
+                    elif element.tag == needed_elements.polygon:
+                        if last_parent_tag == needed_elements.text_line:
+                            line_polygon = element.attrib.get(
+                                "POINTS", self.__poly_from_coords(x, y, w, h)
+                            )
+                        elif last_parent_tag == needed_elements.text_block:
+                            region_polygon = element.attrib.get(
+                                "POINTS",
+                                self.__poly_from_coords(
+                                    x_region, y_region, w_region, h_region
+                                ),
+                            )
+
+                    elif element.tag == needed_elements.text_block:
+                        zone_on_page_count += 1
+                        line_in_zone_count = 0
+                        region_id = element.attrib["ID"]
+                        region_type_id = element.attrib.get("TAGREFS", "")
+                        y_region = int(float(element.attrib.get("VPOS", 0)))
+                        x_region = int(float(element.attrib.get("HPOS", 0)))
+                        h_region = int(float(element.attrib.get("HEIGHT", 0)))
+                        w_region = int(float(element.attrib.get("WIDTH", 0)))
+                        last_parent_tag = element.tag
+
+                    elif element.tag == needed_elements.other_tag:
+                        if "ID" in element.attrib:
+                            tag_dict[element.attrib["ID"]] = element.attrib.get(
+                                "LABEL", ""
+                            )
+
+                    elif element.tag == needed_elements.page:
+                        image_height = int(float(element.attrib.get("HEIGHT", 0)))
+                        image_width = int(float(element.attrib.get("WIDTH", 0)))
+
+                    elif element.tag == needed_elements.file_name:
+                        image_count += 1
+                        image_filename = element.text
+
+                if action == "end":
+                    if element.tag == needed_elements.text_line:
+                        line_length = len(line_text)
+                        cumulative_text_length += line_length
+                        new_row = [
+                            order,
+                            image_count,
+                            int(f"{image_count}0{zone_on_page_count:02}"),
+                            zone_on_page_count,
+                            line_in_zone_count,
+                            y_region,
+                            x_region,
+                            h_region,
+                            w_region,
+                            y,
+                            x,
+                            h,
+                            w,
+                            image_filename,
+                            region_id,
+                            line_id,
+                            line_baseline,
+                            line_polygon,
+                            line_text,
+                            "".join([" " for x in line_text]),
+                            cumulative_text_length,
+                            line_length,
+                            image_height,
+                            image_width,
+                            region_polygon,
+                            tag_dict.get(region_type_id, ""),
+                            region_type_id,
+                            tag_dict.get(line_type_id, ""),
+                            line_type_id,
+                            self._file_path.name,
+                        ]
+                        if order < len(self.__serialized_xml):
+                            self.__serialized_xml.at[
+                                order, self.__serialized_xml.columns
+                            ] = new_row
+                        else:
+                            self.__serialized_xml.append(
+                                pd.DataFrame(
+                                    [new_row], columns=self.__serialized_xml.columns
                                 )
+                            )
 
-                        elif element.tag == needed_elements.text_block:
-                            zone_on_page_count += 1
-                            line_in_zone_count = 0
-                            region_id = element.attrib["ID"]
-                            region_type_id = element.attrib.get("TAGREFS", "")
-                            y_region = int(float(element.attrib.get("VPOS", 0)))
-                            x_region = int(float(element.attrib.get("HPOS", 0)))
-                            h_region = int(float(element.attrib.get("HEIGHT", 0)))
-                            w_region = int(float(element.attrib.get("WIDTH", 0)))
-                            last_parent_tag = element.tag
-
-                        elif element.tag == needed_elements.other_tag:
-                            if "ID" in element.attrib:
-                                tag_dict[element.attrib["ID"]] = element.attrib.get(
-                                    "LABEL", ""
-                                )
-
-                        elif element.tag == needed_elements.page:
-                            image_height = int(float(element.attrib.get("HEIGHT", 0)))
-                            image_width = int(float(element.attrib.get("WIDTH", 0)))
-
-                        elif element.tag == needed_elements.file_name:
-                            image_count += 1
-                            image_filename = element.text
-
-                    if action == "end":
-                        if element.tag == needed_elements.text_line:
-                            line_length = len(line_text)
-                            cumulative_text_length += line_length
-                            new_row = [
-                                order,
-                                image_count,
-                                int(f"{image_count}0{zone_on_page_count:02}"),
-                                zone_on_page_count,
-                                line_in_zone_count,
-                                y_region,
-                                x_region,
-                                h_region,
-                                w_region,
-                                y,
-                                x,
-                                h,
-                                w,
-                                image_filename,
-                                region_id,
-                                line_id,
-                                line_baseline,
-                                line_polygon,
-                                line_text,
-                                "".join([" " for x in line_text]),
-                                cumulative_text_length,
-                                line_length,
-                                image_height,
-                                image_width,
-                                region_polygon,
-                                tag_dict.get(region_type_id, ""),
-                                region_type_id,
-                                tag_dict.get(line_type_id, ""),
-                                line_type_id,
-                                xml_file_path.name,
-                            ]
-                            if order < len(self.__serialized_xml):
-                                self.__serialized_xml.at[
-                                    order, self.__serialized_xml.columns
-                                ] = new_row
-                            else:
-                                self.__serialized_xml.append(
-                                    pd.DataFrame(
-                                        [new_row], columns=self.__serialized_xml.columns
-                                    )
-                                )
-
-                            order += 1
-                        element.clear()
+                        order += 1
+                    element.clear()
 
         # Crop to only rows with values
         self.__serialized_xml = self.__serialized_xml.loc[
